@@ -1,5 +1,9 @@
 var NAVTREEINDEX105 =
 {
+"structztui_1_1ansi_1_1ColorTraits.html#a4a50422755587beec5170f8539e4eaef":[4,0,6,0,6,0],
+"structztui_1_1ansi_1_1ColorTraits_3_01Color_1_1Constant_01_4.html":[3,0,9,0,5],
+"structztui_1_1ansi_1_1ColorTraits_3_01Color_1_1Constant_01_4.html":[4,0,6,0,5],
+"structztui_1_1ansi_1_1ColorTraits_3_01ztui_1_1ColorContext_01_4.html":[3,0,9,0,6],
 "structztui_1_1ansi_1_1ColorTraits_3_01ztui_1_1ColorContext_01_4.html":[4,0,6,0,6],
 "structztui_1_1ctcdetail_1_1ColumnIf.html":[3,0,9,2,0],
 "structztui_1_1ctcdetail_1_1ColumnIf.html":[4,0,6,1,0],
@@ -245,9 +249,5 @@ var NAVTREEINDEX105 =
 "structztui_1_1out_1_1ListLayout_1_1Writer.html#a63efdca39f42884cc6c684d5471fafc2":[3,0,9,5,2,0,8],
 "structztui_1_1out_1_1ListLayout_1_1Writer.html#a63efdca39f42884cc6c684d5471fafc2":[4,0,6,3,2,0,8],
 "structztui_1_1out_1_1ListLayout_1_1Writer.html#a732a15dbd5fea047aefdc5c2501bbe95":[3,0,9,5,2,0,1],
-"structztui_1_1out_1_1ListLayout_1_1Writer.html#a732a15dbd5fea047aefdc5c2501bbe95":[4,0,6,3,2,0,1],
-"structztui_1_1out_1_1ListLayout_1_1Writer.html#a80b26703653143b56aa9aaf75e64b66a":[3,0,9,5,2,0,10],
-"structztui_1_1out_1_1ListLayout_1_1Writer.html#a80b26703653143b56aa9aaf75e64b66a":[4,0,6,3,2,0,10],
-"structztui_1_1out_1_1ListLayout_1_1Writer.html#a9acafc75813ac0c9bdf8fd302e458029":[3,0,9,5,2,0,11],
-"structztui_1_1out_1_1ListLayout_1_1Writer.html#a9acafc75813ac0c9bdf8fd302e458029":[4,0,6,3,2,0,11]
+"structztui_1_1out_1_1ListLayout_1_1Writer.html#a732a15dbd5fea047aefdc5c2501bbe95":[4,0,6,3,2,0,1]
 };
