@@ -1,5 +1,9 @@
 var NAVTREEINDEX113 =
 {
+"structzypp_1_1RepoManagerOptions.html#a1104bb0639969aac2f2753dd7be2ca8a":[3,0,10,201,10],
+"structzypp_1_1RepoManagerOptions.html#a1104bb0639969aac2f2753dd7be2ca8a":[4,0,7,192,10],
+"structzypp_1_1RepoManagerOptions.html#a23e3d95bdc22eb61e8eacfb89249e573":[3,0,10,201,1],
+"structzypp_1_1RepoManagerOptions.html#a23e3d95bdc22eb61e8eacfb89249e573":[4,0,7,192,1],
 "structzypp_1_1RepoManagerOptions.html#a2a99ae5dca4883f2cbae2ca6cdf85a68":[3,0,10,201,4],
 "structzypp_1_1RepoManagerOptions.html#a2a99ae5dca4883f2cbae2ca6cdf85a68":[4,0,7,192,4],
 "structzypp_1_1RepoManagerOptions.html#a47cb4a3fb7a7954f2c8f305526aab771":[3,0,10,201,6],
@@ -245,9 +249,5 @@ var NAVTREEINDEX113 =
 "structzypp_1_1ResolverProblem_1_1Impl.html#a6024d7def0b76f3f0e282c473a85d29a":[3,0,10,209,0,5],
 "structzypp_1_1ResolverProblem_1_1Impl.html#a6024d7def0b76f3f0e282c473a85d29a":[4,0,7,200,0,5],
 "structzypp_1_1ResolverProblem_1_1Impl.html#a6f729dd0cb83526741af026956e96011":[3,0,10,209,0,7],
-"structzypp_1_1ResolverProblem_1_1Impl.html#a6f729dd0cb83526741af026956e96011":[4,0,7,200,0,7],
-"structzypp_1_1ResolverProblem_1_1Impl.html#a88dc5a682c90d96062bbe203fdf419b1":[3,0,10,209,0,3],
-"structzypp_1_1ResolverProblem_1_1Impl.html#a88dc5a682c90d96062bbe203fdf419b1":[4,0,7,200,0,3],
-"structzypp_1_1ResolverProblem_1_1Impl.html#a8ad08889cf461d9c47e4f37b5e78f496":[3,0,10,209,0,0],
-"structzypp_1_1ResolverProblem_1_1Impl.html#a8ad08889cf461d9c47e4f37b5e78f496":[4,0,7,200,0,0]
+"structzypp_1_1ResolverProblem_1_1Impl.html#a6f729dd0cb83526741af026956e96011":[4,0,7,200,0,7]
 };
