@@ -1,5 +1,9 @@
 var NAVTREEINDEX116 =
 {
+"structzypp_1_1base_1_1logger_1_1LogControlImpl.html#a6550171e9c05d7bc0b77f3662c60a47a":[3,0,10,2,0,0,13],
+"structzypp_1_1base_1_1logger_1_1LogControlImpl.html#a6550171e9c05d7bc0b77f3662c60a47a":[4,0,7,1,0,0,13],
+"structzypp_1_1base_1_1logger_1_1LogControlImpl.html#a6eb55dbf038ea42f6e012a78b5b95b62":[3,0,10,2,0,0,4],
+"structzypp_1_1base_1_1logger_1_1LogControlImpl.html#a6eb55dbf038ea42f6e012a78b5b95b62":[4,0,7,1,0,0,4],
 "structzypp_1_1base_1_1logger_1_1LogControlImpl.html#a762cef18d3f937d0f27be53ec54a6102":[3,0,10,2,0,0,8],
 "structzypp_1_1base_1_1logger_1_1LogControlImpl.html#a762cef18d3f937d0f27be53ec54a6102":[4,0,7,1,0,0,8],
 "structzypp_1_1base_1_1logger_1_1LogControlImpl.html#a87b22b4c5b657f8999f03b2655ae379d":[3,0,10,2,0,0,2],
@@ -245,9 +249,5 @@ var NAVTREEINDEX116 =
 "structzypp_1_1debug_1_1TraceCAD.html#a239653f9797c9dba2d2f854352495d35":[3,0,10,5,3,6],
 "structzypp_1_1debug_1_1TraceCAD.html#a239653f9797c9dba2d2f854352495d35":[4,0,7,4,3,6],
 "structzypp_1_1debug_1_1TraceCAD.html#a662e3bdc62ecb2feeb7f1b442e9774cb":[3,0,10,5,3,2],
-"structzypp_1_1debug_1_1TraceCAD.html#a662e3bdc62ecb2feeb7f1b442e9774cb":[4,0,7,4,3,2],
-"structzypp_1_1debug_1_1TraceCAD.html#a73c84dcc77ae9e6a7c21b66bf46e874b":[3,0,10,5,3,5],
-"structzypp_1_1debug_1_1TraceCAD.html#a73c84dcc77ae9e6a7c21b66bf46e874b":[4,0,7,4,3,5],
-"structzypp_1_1debug_1_1TraceCAD.html#ab7f8e8b6f4f168dbae14fe42d8871b90":[3,0,10,5,3,4],
-"structzypp_1_1debug_1_1TraceCAD.html#ab7f8e8b6f4f168dbae14fe42d8871b90":[4,0,7,4,3,4]
+"structzypp_1_1debug_1_1TraceCAD.html#a662e3bdc62ecb2feeb7f1b442e9774cb":[4,0,7,4,3,2]
 };
