@@ -1,5 +1,7 @@
 var NAVTREEINDEX19 =
 {
+"classzypp_1_1IdStringType.html#ae874af643bf9a9d9211d94e107a654bf":[3,0,10,133,21],
+"classzypp_1_1IdStringType.html#ae874af643bf9a9d9211d94e107a654bf":[4,0,7,124,21],
 "classzypp_1_1IdStringType.html#aec4135e45049399405a16a8891d080c6":[3,0,10,133,17],
 "classzypp_1_1IdStringType.html#aec4135e45049399405a16a8891d080c6":[4,0,7,124,17],
 "classzypp_1_1IdStringType.html#af7f4ac5865481c3c50221f16fc139a52":[3,0,10,133,35],
@@ -247,7 +249,5 @@ var NAVTREEINDEX19 =
 "classzypp_1_1Locale.html#a92f8092d4b84ea1de164f325c4991b6b":[3,0,10,144,13],
 "classzypp_1_1Locale.html#a92f8092d4b84ea1de164f325c4991b6b":[4,0,7,135,13],
 "classzypp_1_1Locale.html#aa3365d9edc6a87956394ad73372cdba1":[3,0,10,144,3],
-"classzypp_1_1Locale.html#aa3365d9edc6a87956394ad73372cdba1":[4,0,7,135,3],
-"classzypp_1_1Locale.html#ad0fd5ccb217023b2966b6c6b363c6356":[3,0,10,144,12],
-"classzypp_1_1Locale.html#ad0fd5ccb217023b2966b6c6b363c6356":[4,0,7,135,12]
+"classzypp_1_1Locale.html#aa3365d9edc6a87956394ad73372cdba1":[4,0,7,135,3]
 };
