@@ -1,5 +1,7 @@
 var NAVTREEINDEX24 =
 {
+"classzypp_1_1Pathname.html#a8526d2d0d6d86a63a1e61a4925e5a855":[4,0,7,164,42],
+"classzypp_1_1Pathname.html#a86e75b01ef8b2f4685729c53c57b5af1":[3,0,10,173,40],
 "classzypp_1_1Pathname.html#a86e75b01ef8b2f4685729c53c57b5af1":[4,0,7,164,40],
 "classzypp_1_1Pathname.html#a871264a0e8d298e8068e2a5e1cb26653":[3,0,10,173,11],
 "classzypp_1_1Pathname.html#a871264a0e8d298e8068e2a5e1cb26653":[4,0,7,164,11],
@@ -247,7 +249,5 @@ var NAVTREEINDEX24 =
 "classzypp_1_1PluginFrame.html#a992e348f860dd93f9504287ff1adc601":[4,0,7,167,45],
 "classzypp_1_1PluginFrame.html#a99701c9d68c205b0a3278b187420b0c1":[3,0,10,176,61],
 "classzypp_1_1PluginFrame.html#a99701c9d68c205b0a3278b187420b0c1":[4,0,7,167,61],
-"classzypp_1_1PluginFrame.html#a9fb98c741aee3f8025ec2a034988211a":[3,0,10,176,46],
-"classzypp_1_1PluginFrame.html#a9fb98c741aee3f8025ec2a034988211a":[4,0,7,167,46],
-"classzypp_1_1PluginFrame.html#aa1b39e476130051c28993730766d05c6":[3,0,10,176,9]
+"classzypp_1_1PluginFrame.html#a9fb98c741aee3f8025ec2a034988211a":[3,0,10,176,46]
 };
