@@ -1,5 +1,7 @@
 var NAVTREEINDEX25 =
 {
+"classzypp_1_1PluginFrame.html#a9fb98c741aee3f8025ec2a034988211a":[4,0,7,167,46],
+"classzypp_1_1PluginFrame.html#aa1b39e476130051c28993730766d05c6":[3,0,10,176,9],
 "classzypp_1_1PluginFrame.html#aa1b39e476130051c28993730766d05c6":[4,0,7,167,9],
 "classzypp_1_1PluginFrame.html#aa30b1bb82236588b32f6e4d77db265c0":[3,0,10,176,22],
 "classzypp_1_1PluginFrame.html#aa30b1bb82236588b32f6e4d77db265c0":[4,0,7,167,22],
@@ -247,7 +249,5 @@ var NAVTREEINDEX25 =
 "classzypp_1_1PoolItemBest.html#a740279c04dbc75dd383c3e749d2e8249":[4,0,7,172,16],
 "classzypp_1_1PoolItemBest.html#a7c054e85a284f6fb833da7c9f940bbc1":[3,0,10,715],
 "classzypp_1_1PoolItemBest.html#a7c054e85a284f6fb833da7c9f940bbc1":[3,0,10,181,28],
-"classzypp_1_1PoolItemBest.html#a7c054e85a284f6fb833da7c9f940bbc1":[4,0,7,172,28],
-"classzypp_1_1PoolItemBest.html#a7c3502b6987a8a6f380630a75e956640":[3,0,10,181,14],
-"classzypp_1_1PoolItemBest.html#a7c3502b6987a8a6f380630a75e956640":[4,0,7,172,14]
+"classzypp_1_1PoolItemBest.html#a7c054e85a284f6fb833da7c9f940bbc1":[4,0,7,172,28]
 };
