@@ -1,5 +1,7 @@
 var NAVTREEINDEX26 =
 {
+"classzypp_1_1PoolItemBest.html#a7c3502b6987a8a6f380630a75e956640":[3,0,10,181,14],
+"classzypp_1_1PoolItemBest.html#a7c3502b6987a8a6f380630a75e956640":[4,0,7,172,14],
 "classzypp_1_1PoolItemBest.html#a8de99c8d9e2c1c592e114ac112a944ac":[3,0,10,181,17],
 "classzypp_1_1PoolItemBest.html#a8de99c8d9e2c1c592e114ac112a944ac":[4,0,7,172,17],
 "classzypp_1_1PoolItemBest.html#a8ec6cba0d88100156eaa6d9cf9cc79b8":[3,0,10,181,13],
@@ -247,7 +249,5 @@ var NAVTREEINDEX26 =
 "classzypp_1_1PoolQueryResult.html#ae2f8b05cddf9b4ad4b042ba63d38b8b9":[4,0,7,176,23],
 "classzypp_1_1PoolQueryResult.html#ae92817c042d9ecd3dd6424995e774ae4":[3,0,10,185,13],
 "classzypp_1_1PoolQueryResult.html#ae92817c042d9ecd3dd6424995e774ae4":[4,0,7,176,13],
-"classzypp_1_1PoolQueryResult.html#ae982931cac531407135abb4132d08cfb":[3,0,10,185,19],
-"classzypp_1_1PoolQueryResult.html#ae982931cac531407135abb4132d08cfb":[4,0,7,176,19],
-"classzypp_1_1PoolQueryResult.html#af3d01c8028619a72fa28974afa0297b0":[3,0,10,185,7]
+"classzypp_1_1PoolQueryResult.html#ae982931cac531407135abb4132d08cfb":[3,0,10,185,19]
 };
