@@ -1,5 +1,7 @@
 var NAVTREEINDEX27 =
 {
+"classzypp_1_1PoolQueryResult.html#ae982931cac531407135abb4132d08cfb":[4,0,7,176,19],
+"classzypp_1_1PoolQueryResult.html#af3d01c8028619a72fa28974afa0297b0":[3,0,10,185,7],
 "classzypp_1_1PoolQueryResult.html#af3d01c8028619a72fa28974afa0297b0":[4,0,7,176,7],
 "classzypp_1_1PoolQuery_1_1Impl.html":[3,0,10,183,0],
 "classzypp_1_1PoolQuery_1_1Impl.html":[4,0,7,174,0],
@@ -247,7 +249,5 @@ var NAVTREEINDEX27 =
 "classzypp_1_1ProgressData.html#a8ed05bfc5a8e3bf37ca4cee5a3b282e4":[3,0,10,188,8],
 "classzypp_1_1ProgressData.html#a8ed05bfc5a8e3bf37ca4cee5a3b282e4":[4,0,7,179,8],
 "classzypp_1_1ProgressData.html#a9184e39f352f8f36f8117072e604879a":[3,0,10,188,10],
-"classzypp_1_1ProgressData.html#a9184e39f352f8f36f8117072e604879a":[4,0,7,179,10],
-"classzypp_1_1ProgressData.html#a92d26ba0ea8fa3e46c43ed55043980a3":[3,0,10,188,13],
-"classzypp_1_1ProgressData.html#a92d26ba0ea8fa3e46c43ed55043980a3":[4,0,7,179,13]
+"classzypp_1_1ProgressData.html#a9184e39f352f8f36f8117072e604879a":[4,0,7,179,10]
 };
