@@ -1,5 +1,7 @@
 var NAVTREEINDEX31 =
 {
+"classzypp_1_1ResObject.html#afae896294e962b13f9326fbf10babeae":[3,0,10,206,1],
+"classzypp_1_1ResObject.html#afae896294e962b13f9326fbf10babeae":[4,0,7,197,1],
 "classzypp_1_1ResPool.html":[3,0,10,210],
 "classzypp_1_1ResPool.html":[4,0,7,201],
 "classzypp_1_1ResPool.html#a04729e0c24fe8690d61baeb1fcbe6108":[3,0,10,210,3],
@@ -247,7 +249,5 @@ var NAVTREEINDEX31 =
 "classzypp_1_1ResPoolProxy.html#a97eee9a4b0c3dd24cb9d8df9e2d87efe":[3,0,10,211,25],
 "classzypp_1_1ResPoolProxy.html#a97eee9a4b0c3dd24cb9d8df9e2d87efe":[4,0,7,202,25],
 "classzypp_1_1ResPoolProxy.html#a9b5289fdd011e2b14262c218d4f651c7":[3,0,10,211,13],
-"classzypp_1_1ResPoolProxy.html#a9b5289fdd011e2b14262c218d4f651c7":[4,0,7,202,13],
-"classzypp_1_1ResPoolProxy.html#a9c6ae8e0697209c00c8027945271ff1c":[3,0,10,211,20],
-"classzypp_1_1ResPoolProxy.html#a9c6ae8e0697209c00c8027945271ff1c":[4,0,7,202,20]
+"classzypp_1_1ResPoolProxy.html#a9b5289fdd011e2b14262c218d4f651c7":[4,0,7,202,13]
 };
