@@ -1,5 +1,7 @@
 var NAVTREEINDEX34 =
 {
+"classzypp_1_1Resolver.html#a5c0474a15c1e04baf81aaa6e9a03fd9b":[3,0,10,208,36],
+"classzypp_1_1Resolver.html#a5c0474a15c1e04baf81aaa6e9a03fd9b":[4,0,7,199,36],
 "classzypp_1_1Resolver.html#a5e2fd7674df4359c2096b0443c171738":[3,0,10,208,7],
 "classzypp_1_1Resolver.html#a5e2fd7674df4359c2096b0443c171738":[4,0,7,199,7],
 "classzypp_1_1Resolver.html#a5e9335d04e1a048f48a61ead31861a76":[3,0,10,208,77],
@@ -247,7 +249,5 @@ var NAVTREEINDEX34 =
 "classzypp_1_1ServiceInfo.html#a80bb4170d87c145902eecb088517801a":[4,0,7,213,20],
 "classzypp_1_1ServiceInfo.html#a82278688431ad6fae86d60e600bb4133":[3,0,10,222,9],
 "classzypp_1_1ServiceInfo.html#a82278688431ad6fae86d60e600bb4133":[4,0,7,213,9],
-"classzypp_1_1ServiceInfo.html#a89403fc613219b4af63fe0a5ae4cceee":[3,0,10,222,47],
-"classzypp_1_1ServiceInfo.html#a89403fc613219b4af63fe0a5ae4cceee":[4,0,7,213,47],
-"classzypp_1_1ServiceInfo.html#a961ca8546daf15766ef1e7c8f29d0363":[3,0,10,222,40]
+"classzypp_1_1ServiceInfo.html#a89403fc613219b4af63fe0a5ae4cceee":[3,0,10,222,47]
 };
