@@ -1,5 +1,9 @@
 var NAVTREEINDEX41 =
 {
+"classzypp_1_1bit_1_1BitField.html#a43ecd037a7bf0f7b631ef4346fbf2cd3":[4,0,7,2,1,27],
+"classzypp_1_1bit_1_1BitField.html#a5267782b6446f155bbab634055126295":[3,0,10,3,1,0],
+"classzypp_1_1bit_1_1BitField.html#a5267782b6446f155bbab634055126295":[4,0,7,2,1,0],
+"classzypp_1_1bit_1_1BitField.html#a624c1083fb1dfb1f629c72fc351f0630":[3,0,10,3,9],
 "classzypp_1_1bit_1_1BitField.html#a624c1083fb1dfb1f629c72fc351f0630":[3,0,10,3,1,28],
 "classzypp_1_1bit_1_1BitField.html#a624c1083fb1dfb1f629c72fc351f0630":[4,0,7,2,1,28],
 "classzypp_1_1bit_1_1BitField.html#a6775fcc5f723d8760d395d5397bc50a1":[3,0,10,3,1,2],
@@ -245,9 +249,5 @@ var NAVTREEINDEX41 =
 "classzypp_1_1detail_1_1PoolQueryIterator.html#abb49b4fc61fcd941834a8bb04efa2fac":[3,0,10,6,5,0],
 "classzypp_1_1detail_1_1PoolQueryIterator.html#abb49b4fc61fcd941834a8bb04efa2fac":[4,0,7,5,5,0],
 "classzypp_1_1detail_1_1PoolQueryIterator.html#ac09f73e325921cc50ebcd96bed0f8096":[3,0,10,6,5,12],
-"classzypp_1_1detail_1_1PoolQueryIterator.html#ac09f73e325921cc50ebcd96bed0f8096":[4,0,7,5,5,12],
-"classzypp_1_1detail_1_1PoolQueryIterator.html#ac6f8f2c9b584df977c49aa755eeb8a05":[3,0,10,6,13],
-"classzypp_1_1detail_1_1PoolQueryIterator.html#ac6f8f2c9b584df977c49aa755eeb8a05":[3,0,10,6,5,13],
-"classzypp_1_1detail_1_1PoolQueryIterator.html#ac6f8f2c9b584df977c49aa755eeb8a05":[4,0,7,5,5,13],
-"classzypp_1_1detail_1_1PoolQueryIterator.html#ae71af50162176487d842ab540ad73128":[3,0,10,6,5,3]
+"classzypp_1_1detail_1_1PoolQueryIterator.html#ac09f73e325921cc50ebcd96bed0f8096":[4,0,7,5,5,12]
 };
