@@ -1,5 +1,9 @@
 var NAVTREEINDEX53 =
 {
+"classzypp_1_1media_1_1multifetchrequest.html#a6b3c9ae3c9e8b8d6353055d0cef0e462":[4,0,7,22,72,38],
+"classzypp_1_1media_1_1multifetchrequest.html#a7bae8acb734ef8d0359be062a7811c0c":[3,0,10,25,72,14],
+"classzypp_1_1media_1_1multifetchrequest.html#a7bae8acb734ef8d0359be062a7811c0c":[4,0,7,22,72,14],
+"classzypp_1_1media_1_1multifetchrequest.html#a8c4fe0eb7c601f1b8631f71f36d46114":[3,0,10,25,72,12],
 "classzypp_1_1media_1_1multifetchrequest.html#a8c4fe0eb7c601f1b8631f71f36d46114":[4,0,7,22,72,12],
 "classzypp_1_1media_1_1multifetchrequest.html#a8f102b03ef173ff00ebd78cbf519619d":[3,0,10,25,72,9],
 "classzypp_1_1media_1_1multifetchrequest.html#a8f102b03ef173ff00ebd78cbf519619d":[4,0,7,22,72,9],
@@ -245,9 +249,5 @@ var NAVTREEINDEX53 =
 "classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#ad170f52247164201c99b68c75a832edb":[4,0,7,23,0,5,6],
 "classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#ad38e850025d09aa09633fe47952e7b85":[3,0,10,26,0,5,7],
 "classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#ad38e850025d09aa09633fe47952e7b85":[4,0,7,23,0,5,7],
-"classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#add9658cc66e5f7cd9ff648336c450899":[3,0,10,26,0,5,17],
-"classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#add9658cc66e5f7cd9ff648336c450899":[4,0,7,23,0,5,17],
-"classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#ae1c9321bcfb491effb3ef02b16c44198":[3,0,10,26,0,5,32],
-"classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#ae1c9321bcfb491effb3ef02b16c44198":[4,0,7,23,0,5,32],
-"classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#ae575a5dcc3bfc41e239404c7db8d11fc":[3,0,10,26,0,5,24]
+"classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#add9658cc66e5f7cd9ff648336c450899":[3,0,10,26,0,5,17]
 };
