@@ -1,5 +1,9 @@
 var NAVTREEINDEX66 =
 {
+"classzypp_1_1solver_1_1detail_1_1SolverQueueItemLock.html#a945e89151826fa8f5e14934999f10826":[3,0,10,39,0,9,0],
+"classzypp_1_1solver_1_1detail_1_1SolverQueueItemLock.html#a945e89151826fa8f5e14934999f10826":[4,0,7,33,0,9,0],
+"classzypp_1_1solver_1_1detail_1_1SolverQueueItemLock.html#aeeeb9e55eeb099351da348225c8176ec":[3,0,10,39,0,9,7],
+"classzypp_1_1solver_1_1detail_1_1SolverQueueItemLock.html#aeeeb9e55eeb099351da348225c8176ec":[4,0,7,33,0,9,7],
 "classzypp_1_1solver_1_1detail_1_1SolverQueueItemUpdate.html":[3,0,10,39,0,10],
 "classzypp_1_1solver_1_1detail_1_1SolverQueueItemUpdate.html":[4,0,7,33,0,10],
 "classzypp_1_1solver_1_1detail_1_1SolverQueueItemUpdate.html#a0b0461ba7421aa3d864c6260fe78efe9":[3,0,10,39,0,10,5],
@@ -245,9 +249,5 @@ var NAVTREEINDEX66 =
 "classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html":[3,0,10,43,1,0],
 "classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html":[4,0,7,36,1,0],
 "classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html#a05b7de9d6d9bf2836e233407f09b419a":[3,0,10,43,1,0,5],
-"classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html#a05b7de9d6d9bf2836e233407f09b419a":[4,0,7,36,1,0,5],
-"classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html#a0c21953a45c3c2cd3f1094055c6591a6":[3,0,10,43,1,0,7],
-"classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html#a0c21953a45c3c2cd3f1094055c6591a6":[4,0,7,36,1,0,7],
-"classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html#a473ded83f1841a12ae0654063bbb20db":[3,0,10,43,1,0,13],
-"classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html#a473ded83f1841a12ae0654063bbb20db":[4,0,7,36,1,0,13]
+"classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html#a05b7de9d6d9bf2836e233407f09b419a":[4,0,7,36,1,0,5]
 };
