@@ -1,5 +1,9 @@
 var NAVTREEINDEX67 =
 {
+"classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html#a0c21953a45c3c2cd3f1094055c6591a6":[3,0,10,43,1,0,7],
+"classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html#a0c21953a45c3c2cd3f1094055c6591a6":[4,0,7,36,1,0,7],
+"classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html#a473ded83f1841a12ae0654063bbb20db":[3,0,10,43,1,0,13],
+"classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html#a473ded83f1841a12ae0654063bbb20db":[4,0,7,36,1,0,13],
 "classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html#a5d8d4180c80e8c02d3eb1167f4ea8d28":[3,0,10,43,1,0,8],
 "classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html#a5d8d4180c80e8c02d3eb1167f4ea8d28":[4,0,7,36,1,0,8],
 "classzypp_1_1target_1_1CommitPackageCache_1_1Impl.html#a643860c5e9e3f8e024aac763e234efb8":[3,0,10,43,1,0,3],
@@ -245,9 +249,5 @@ var NAVTREEINDEX67 =
 "classzypp_1_1target_1_1RpmPostTransCollector_1_1Impl.html#af3bfcd2915d77bcfaad2709a1c36f8aa":[4,0,7,36,12,0,17],
 "classzypp_1_1target_1_1RpmRemovePackageReceiver.html":[3,0,10,43,13],
 "classzypp_1_1target_1_1RpmRemovePackageReceiver.html":[4,0,7,36,13],
-"classzypp_1_1target_1_1RpmRemovePackageReceiver.html#a1c90b900ae52273170071ee7986315cc":[3,0,10,43,13,11],
-"classzypp_1_1target_1_1RpmRemovePackageReceiver.html#a1c90b900ae52273170071ee7986315cc":[4,0,7,36,13,11],
-"classzypp_1_1target_1_1RpmRemovePackageReceiver.html#a20eb4d09bbc510ad57a190d518d64235":[3,0,10,43,13,0],
-"classzypp_1_1target_1_1RpmRemovePackageReceiver.html#a20eb4d09bbc510ad57a190d518d64235":[4,0,7,36,13,0],
-"classzypp_1_1target_1_1RpmRemovePackageReceiver.html#a30dbbe7aa9d990c43bdc28876dbd3456":[3,0,10,43,13,3]
+"classzypp_1_1target_1_1RpmRemovePackageReceiver.html#a1c90b900ae52273170071ee7986315cc":[3,0,10,43,13,11]
 };
