@@ -1,5 +1,9 @@
 var NAVTREEINDEX69 =
 {
+"classzypp_1_1target_1_1rpm_1_1BinHeader_1_1intList.html#af911ad68f3e9be6073af7d48308c7cbc":[4,0,7,36,0,1,0,6],
+"classzypp_1_1target_1_1rpm_1_1BinHeader_1_1stringList.html":[3,0,10,43,0,2,1],
+"classzypp_1_1target_1_1rpm_1_1BinHeader_1_1stringList.html":[4,0,7,36,0,1,1],
+"classzypp_1_1target_1_1rpm_1_1BinHeader_1_1stringList.html#a106e8f65f15007fe790a7e6dce9e97c1":[3,0,10,43,0,2,1,5],
 "classzypp_1_1target_1_1rpm_1_1BinHeader_1_1stringList.html#a106e8f65f15007fe790a7e6dce9e97c1":[4,0,7,36,0,1,1,5],
 "classzypp_1_1target_1_1rpm_1_1BinHeader_1_1stringList.html#a11e32763e36c21004da696f8b80eb0ec":[3,0,10,43,0,2,1,2],
 "classzypp_1_1target_1_1rpm_1_1BinHeader_1_1stringList.html#a11e32763e36c21004da696f8b80eb0ec":[4,0,7,36,0,1,1,2],
@@ -245,9 +249,5 @@ var NAVTREEINDEX69 =
 "classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a0e7f5499038020ea53d270b840a505b2":[4,0,7,36,0,22,26],
 "classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a1ea502f3665d033a28940b88540ad6ed":[3,0,10,43,0,23,39],
 "classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a1ea502f3665d033a28940b88540ad6ed":[4,0,7,36,0,22,39],
-"classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a1f7de1d7ce87f657ed21517edf655b8c":[3,0,10,43,0,23,11],
-"classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a1f7de1d7ce87f657ed21517edf655b8c":[4,0,7,36,0,22,11],
-"classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a250e494f2d357125225cc0bf4dc47486":[3,0,10,43,0,23,47],
-"classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a250e494f2d357125225cc0bf4dc47486":[4,0,7,36,0,22,47],
-"classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a289c3e90b6d1a4f9a43522d0669b7c10":[3,0,10,43,0,23,25]
+"classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a1f7de1d7ce87f657ed21517edf655b8c":[3,0,10,43,0,23,11]
 };
