@@ -1,5 +1,9 @@
 var NAVTREEINDEX79 =
 {
+"classzyppng_1_1HeaderValueMap.html#a17748710196d12643badf63ebbba8012":[3,0,13,94,8],
+"classzyppng_1_1HeaderValueMap.html#a17748710196d12643badf63ebbba8012":[4,0,9,56,8],
+"classzyppng_1_1HeaderValueMap.html#a1baabf39363d45d24052c8ca8344ab81":[3,0,13,94,2],
+"classzyppng_1_1HeaderValueMap.html#a1baabf39363d45d24052c8ca8344ab81":[4,0,9,56,2],
 "classzyppng_1_1HeaderValueMap.html#a1dc8fd6c12bce0cc8ffc661ed41fd748":[3,0,13,94,28],
 "classzyppng_1_1HeaderValueMap.html#a1dc8fd6c12bce0cc8ffc661ed41fd748":[4,0,9,56,28],
 "classzyppng_1_1HeaderValueMap.html#a30a04605ececcc61cddb01f52050af61":[3,0,13,94,31],
@@ -245,9 +249,5 @@ var NAVTREEINDEX79 =
 "classzyppng_1_1IODevicePrivate.html#a31c31d06536949217727145a346ddc4c":[3,0,13,99,9],
 "classzyppng_1_1IODevicePrivate.html#a31c31d06536949217727145a346ddc4c":[4,0,9,61,9],
 "classzyppng_1_1IODevicePrivate.html#a35cb5ceb4b9f5a42b51513bec3c025db":[3,0,13,99,7],
-"classzyppng_1_1IODevicePrivate.html#a35cb5ceb4b9f5a42b51513bec3c025db":[4,0,9,61,7],
-"classzyppng_1_1IODevicePrivate.html#a582623d8b24744d835dda88005a2196a":[3,0,13,99,1],
-"classzyppng_1_1IODevicePrivate.html#a582623d8b24744d835dda88005a2196a":[4,0,9,61,1],
-"classzyppng_1_1IODevicePrivate.html#a752ba8b4690dd2f6524d0ec2da69fced":[3,0,13,99,5],
-"classzyppng_1_1IODevicePrivate.html#a752ba8b4690dd2f6524d0ec2da69fced":[4,0,9,61,5]
+"classzyppng_1_1IODevicePrivate.html#a35cb5ceb4b9f5a42b51513bec3c025db":[4,0,9,61,7]
 };
