@@ -1,5 +1,9 @@
 var NAVTREEINDEX83 =
 {
+"classzyppng_1_1ProgressObserver.html#a9569ee9fc896963102cb3d3bd0d10ec1":[3,0,13,123,25],
+"classzyppng_1_1ProgressObserver.html#a9569ee9fc896963102cb3d3bd0d10ec1":[4,0,9,85,25],
+"classzyppng_1_1ProgressObserver.html#a95c4f01b8bc3337171ae0659f2652698":[3,0,13,123,15],
+"classzyppng_1_1ProgressObserver.html#a95c4f01b8bc3337171ae0659f2652698":[4,0,9,85,15],
 "classzyppng_1_1ProgressObserver.html#a960e3e188afd8050006e7533eaa27b51":[3,0,13,123,22],
 "classzyppng_1_1ProgressObserver.html#a960e3e188afd8050006e7533eaa27b51":[4,0,9,85,22],
 "classzyppng_1_1ProgressObserver.html#a96583bde6ce2dc5a3b5c14a696168efa":[3,0,13,123,11],
@@ -245,9 +249,5 @@ var NAVTREEINDEX83 =
 "classzyppng_1_1ProvideFileSpec.html#a83bbdd1b5632a527e60e89d1d0116489":[3,0,13,128,20],
 "classzyppng_1_1ProvideFileSpec.html#a83bbdd1b5632a527e60e89d1d0116489":[4,0,9,90,20],
 "classzyppng_1_1ProvideFileSpec.html#a91408d5bd8f25fd5a854a4d45e1cd229":[3,0,13,128,18],
-"classzyppng_1_1ProvideFileSpec.html#a91408d5bd8f25fd5a854a4d45e1cd229":[4,0,9,90,18],
-"classzyppng_1_1ProvideFileSpec.html#a9bb8aa8ebc8d2ec401d315c5a6f3e810":[3,0,13,128,19],
-"classzyppng_1_1ProvideFileSpec.html#a9bb8aa8ebc8d2ec401d315c5a6f3e810":[4,0,9,90,19],
-"classzyppng_1_1ProvideFileSpec.html#a9c02380ece40166a5de6f3fb724b76a5":[3,0,13,128,7],
-"classzyppng_1_1ProvideFileSpec.html#a9c02380ece40166a5de6f3fb724b76a5":[4,0,9,90,7]
+"classzyppng_1_1ProvideFileSpec.html#a91408d5bd8f25fd5a854a4d45e1cd229":[4,0,9,90,18]
 };
